@@ -262,17 +262,6 @@ class Document(metaclass=MetaDocument):
         await cls.collection.insert_one(kwargs)
         return cls(**kwargs)
 
-    async def _delete_by_prop(self, relations):
-
-        for prop, delete_info in relations.items():
-
-            property_name = prop.fget.__name__
-            try:
-                for doc in await getattr(self, property_name):
-                    await doc.delete()
-            except DocumentDoesntExist:
-                continue
-
     async def _delete_related(self):
         """Deletes related documents or pops field values."""
 
